==> openshift-model-operatorhub-4.11.2-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/CustomResourceDefinitionsFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface CustomResourceDefinitionsFluent<A extends CustomResourceDefinitionsFluent<A>> extends Fluent<A>{


    public A addToOwned(int index,CRDDescription item);
    public A setToOwned(int index,CRDDescription item);
    public A addToOwned(CRDDescription... items);
    public A addAllToOwned(Collection<CRDDescription> items);
    public A removeFromOwned(CRDDescription... items);
    public A removeAllFromOwned(Collection<CRDDescription> items);
    public A removeMatchingFromOwned(io.fabric8.kubernetes.api.builder.Predicate<CRDDescriptionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildOwned instead.
 * @return The buildable object.
 */
@Deprecated public List<CRDDescription> getOwned();
    public List<CRDDescription> buildOwned();
    public CRDDescription buildOwned(int index);
    public CRDDescription buildFirstOwned();
    public CRDDescription buildLastOwned();
    public CRDDescription buildMatchingOwned(io.fabric8.kubernetes.api.builder.Predicate<CRDDescriptionBuilder> predicate);
    public Boolean hasMatchingOwned(io.fabric8.kubernetes.api.builder.Predicate<CRDDescriptionBuilder> predicate);
    public A withOwned(List<CRDDescription> owned);
    public A withOwned(CRDDescription... owned);
    public Boolean hasOwned();
    public CustomResourceDefinitionsFluent.OwnedNested<A> addNewOwned();
    public CustomResourceDefinitionsFluent.OwnedNested<A> addNewOwnedLike(CRDDescription item);
    public CustomResourceDefinitionsFluent.OwnedNested<A> setNewOwnedLike(int index,CRDDescription item);
    public CustomResourceDefinitionsFluent.OwnedNested<A> editOwned(int index);
    public CustomResourceDefinitionsFluent.OwnedNested<A> editFirstOwned();
    public CustomResourceDefinitionsFluent.OwnedNested<A> editLastOwned();
    public CustomResourceDefinitionsFluent.OwnedNested<A> editMatchingOwned(io.fabric8.kubernetes.api.builder.Predicate<CRDDescriptionBuilder> predicate);
    public A addToRequired(int index,CRDDescription item);
    public A setToRequired(int index,CRDDescription item);
    public A addToRequired(CRDDescription... items);
    public A addAllToRequired(Collection<CRDDescription> items);
    public A removeFromRequired(CRDDescription... items);
    public A removeAllFromRequired(Collection<CRDDescription> items);
    public A removeMatchingFromRequired(io.fabric8.kubernetes.api.builder.Predicate<CRDDescriptionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRequired instead.
 * @return The buildable object.
 */
@Deprecated public List<CRDDescription> getRequired();
    public List<CRDDescription> buildRequired();
    public CRDDescription buildRequired(int index);
    public CRDDescription buildFirstRequired();
    public CRDDescription buildLastRequired();
    public CRDDescription buildMatchingRequired(io.fabric8.kubernetes.api.builder.Predicate<CRDDescriptionBuilder> predicate);
    public Boolean hasMatchingRequired(io.fabric8.kubernetes.api.builder.Predicate<CRDDescriptionBuilder> predicate);
    public A withRequired(List<CRDDescription> required);
    public A withRequired(CRDDescription... required);
    public Boolean hasRequired();
    public CustomResourceDefinitionsFluent.RequiredNested<A> addNewRequired();
    public CustomResourceDefinitionsFluent.RequiredNested<A> addNewRequiredLike(CRDDescription item);
    public CustomResourceDefinitionsFluent.RequiredNested<A> setNewRequiredLike(int index,CRDDescription item);
    public CustomResourceDefinitionsFluent.RequiredNested<A> editRequired(int index);
    public CustomResourceDefinitionsFluent.RequiredNested<A> editFirstRequired();
    public CustomResourceDefinitionsFluent.RequiredNested<A> editLastRequired();
    public CustomResourceDefinitionsFluent.RequiredNested<A> editMatchingRequired(io.fabric8.kubernetes.api.builder.Predicate<CRDDescriptionBuilder> predicate);

    public interface OwnedNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CRDDescriptionFluent<CustomResourceDefinitionsFluent.OwnedNested<N>>{

        
    public N and();    public N endOwned();
}
    public interface RequiredNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CRDDescriptionFluent<CustomResourceDefinitionsFluent.RequiredNested<N>>{

        
    public N and();    public N endRequired();
}


}

==> openshift-model-operatorhub-5.0.1-sources.jar: annotations/io/fabric8/openshift/api/model/operatorhub/v1alpha1/CustomResourceDefinitionsFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface CustomResourceDefinitionsFluent<A extends CustomResourceDefinitionsFluent<A>> extends Fluent<A> {


    public A addToOwned(int index,CRDDescription item);
    public A setToOwned(int index,CRDDescription item);
    public A addToOwned(CRDDescription... items);
    public A addAllToOwned(Collection<CRDDescription> items);
    public A removeFromOwned(CRDDescription... items);
    public A removeAllFromOwned(Collection<CRDDescription> items);
    public A removeMatchingFromOwned(Predicate<CRDDescriptionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildOwned instead.
 * @return The buildable object.
 */
@Deprecated public List<CRDDescription> getOwned();
    public List<CRDDescription> buildOwned();
    public CRDDescription buildOwned(int index);
    public CRDDescription buildFirstOwned();
    public CRDDescription buildLastOwned();
    public CRDDescription buildMatchingOwned(Predicate<CRDDescriptionBuilder> predicate);
    public Boolean hasMatchingOwned(Predicate<CRDDescriptionBuilder> predicate);
    public A withOwned(List<CRDDescription> owned);
    public A withOwned(CRDDescription... owned);
    public Boolean hasOwned();
    public CustomResourceDefinitionsFluent.OwnedNested<A> addNewOwned();
    public CustomResourceDefinitionsFluent.OwnedNested<A> addNewOwnedLike(CRDDescription item);
    public CustomResourceDefinitionsFluent.OwnedNested<A> setNewOwnedLike(int index,CRDDescription item);
    public CustomResourceDefinitionsFluent.OwnedNested<A> editOwned(int index);
    public CustomResourceDefinitionsFluent.OwnedNested<A> editFirstOwned();
    public CustomResourceDefinitionsFluent.OwnedNested<A> editLastOwned();
    public CustomResourceDefinitionsFluent.OwnedNested<A> editMatchingOwned(Predicate<CRDDescriptionBuilder> predicate);
    public A addToRequired(int index,CRDDescription item);
    public A setToRequired(int index,CRDDescription item);
    public A addToRequired(CRDDescription... items);
    public A addAllToRequired(Collection<CRDDescription> items);
    public A removeFromRequired(CRDDescription... items);
    public A removeAllFromRequired(Collection<CRDDescription> items);
    public A removeMatchingFromRequired(Predicate<CRDDescriptionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRequired instead.
 * @return The buildable object.
 */
@Deprecated public List<CRDDescription> getRequired();
    public List<CRDDescription> buildRequired();
    public CRDDescription buildRequired(int index);
    public CRDDescription buildFirstRequired();
    public CRDDescription buildLastRequired();
    public CRDDescription buildMatchingRequired(Predicate<CRDDescriptionBuilder> predicate);
    public Boolean hasMatchingRequired(Predicate<CRDDescriptionBuilder> predicate);
    public A withRequired(List<CRDDescription> required);
    public A withRequired(CRDDescription... required);
    public Boolean hasRequired();
    public CustomResourceDefinitionsFluent.RequiredNested<A> addNewRequired();
    public CustomResourceDefinitionsFluent.RequiredNested<A> addNewRequiredLike(CRDDescription item);
    public CustomResourceDefinitionsFluent.RequiredNested<A> setNewRequiredLike(int index,CRDDescription item);
    public CustomResourceDefinitionsFluent.RequiredNested<A> editRequired(int index);
    public CustomResourceDefinitionsFluent.RequiredNested<A> editFirstRequired();
    public CustomResourceDefinitionsFluent.RequiredNested<A> editLastRequired();
    public CustomResourceDefinitionsFluent.RequiredNested<A> editMatchingRequired(Predicate<CRDDescriptionBuilder> predicate);
    public interface OwnedNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CRDDescriptionFluent<CustomResourceDefinitionsFluent.OwnedNested<N>> {

            public N and();
            public N endOwned();    }


    public interface RequiredNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CRDDescriptionFluent<CustomResourceDefinitionsFluent.RequiredNested<N>> {

            public N and();
            public N endRequired();    }


}
